@@ -13,7 +13,6 @@ use std::{io, path::PathBuf, process, sync::mpsc};
 
 use audio::{AudioModel, AudioOptions};
 use magnetron::effects::{DelayOptions, ReverbOptions, RotaryOptions};
-use midi::TuningMethod;
 use model::{Model, SourceId};
 use nannou::app::App;
 use piano::{Backend, NoAudio, PianoEngine};
@@ -27,7 +26,7 @@ use tune::{
     temperament::{EqualTemperament, TemperamentPreference},
 };
 use tune_cli::{
-    shared::{self, KbmOptions, SclCommand},
+    shared::{self, KbmOptions, MidiOutArgs, SclCommand, TuningMethod},
     CliError, CliResult,
 };
 use view::DynViewModel;
@@ -69,6 +68,7 @@ enum MainOptions {
     Devices,
 }
 
+const TUN_METHOD_ARG: &str = "tun-method";
 #[derive(StructOpt)]
 struct RunOptions {
     /// MIDI target device
@@ -76,8 +76,11 @@ struct RunOptions {
     midi_target: Option<String>,
 
     /// MIDI-out tuning method
-    #[structopt(long = "tun-method", default_value="full", parse(try_from_str=parse_tuning_method))]
-    midi_tuning_method: TuningMethod,
+    #[structopt(long = TUN_METHOD_ARG, parse(try_from_str=shared::parse_tuning_method))]
+    midi_tuning_method: Option<TuningMethod>,
+
+    #[structopt(flatten)]
+    midi_out_args: MidiOutArgs,
 
     /// MIDI source device
     #[structopt(long = "midi-in")]
@@ -289,20 +292,6 @@ struct RotaryParameters {
     rotation_deceleration: f64,
 }
 
-fn parse_tuning_method(src: &str) -> Result<TuningMethod, &'static str> {
-    Ok(match &*src.to_lowercase() {
-        "full" => TuningMethod::FullKeyboard,
-        "octave" => TuningMethod::Octave,
-        "channel" => TuningMethod::ChannelFineTuning,
-        "pitch-bend" => TuningMethod::PitchBend,
-        _ => {
-            return Err(
-                "Invalid tuning method. Should be `full`, `octave`, `channel` or `pitch-bend`",
-            )
-        }
-    })
-}
-
 struct KeyboardColors(Vec<bool>);
 
 fn parse_keyboard_colors(src: &str) -> Result<KeyboardColors, String> {
@@ -386,7 +375,14 @@ fn create_model(kbm: Kbm, options: RunOptions) -> CliResult<Model> {
     let mut backends = Vec::<Box<dyn Backend<SourceId>>>::new();
 
     if let Some(target_port) = options.midi_target {
-        let midi_backend = midi::create(send.clone(), &target_port, options.midi_tuning_method)?;
+        let midi_backend = midi::create(
+            send.clone(),
+            &target_port,
+            &options.midi_out_args,
+            options
+                .midi_tuning_method
+                .ok_or_else(|| format!("MIDI out requires --{} argument", TUN_METHOD_ARG))?,
+        )?;
         backends.push(Box::new(midi_backend));
     }
 
