@@ -13,6 +13,7 @@ use tune::{
     scala::KbmRoot,
     tuning::Scale,
 };
+use tune_cli::shared::TuningMethod;
 
 use crate::{fluid::FluidInfo, midi::MidiInfo, synth::WaveformInfo, Model};
 
@@ -122,14 +123,8 @@ fn render_scale_lines(
         };
 
         draw.line()
-            .start(Point2 {
-                x: pitch_position_on_screen,
-                y: window_rect.top(),
-            })
-            .end(Point2 {
-                x: pitch_position_on_screen,
-                y: window_rect.bottom(),
-            })
+            .start(Point2::new(pitch_position_on_screen, window_rect.top()))
+            .end(Point2::new(pitch_position_on_screen, window_rect.bottom()))
             .color(line_color)
             .weight(2.0);
     }
@@ -157,14 +152,8 @@ fn render_just_ratios_with_deviations(
         let pitch_position_on_screen = (pitch_position - 0.5) * window_rect.w();
 
         draw.line()
-            .start(Point2 {
-                x: pitch_position_on_screen,
-                y: window_rect.top(),
-            })
-            .end(Point2 {
-                x: pitch_position_on_screen,
-                y: window_rect.bottom(),
-            })
+            .start(Point2::new(pitch_position_on_screen, window_rect.top()))
+            .end(Point2::new(pitch_position_on_screen, window_rect.bottom()))
             .color(WHITE)
             .weight(2.0);
 
@@ -313,14 +302,14 @@ fn render_hud(model: &Model, draw: &Draw, window_rect: Rect) {
 
     writeln!(
         hud_text,
-        "Continuous [Alt+C]: {continuous}\n\
+        "Tuning Mode [Alt+T]: {tuning_mode:?}\n\
          Legato [Alt+L]: {legato}\n\
          Reverb [Ctrl+F8]: {reverb}\n\
          Delay [Ctrl+F9]: {delay}\n\
          Rotary Speaker [Ctrl+/F10]: {rotary}\n\
          Recording [Space]: {recording}\n\
          Range [Alt+/Scroll]: {from:.0}..{to:.0} Hz",
-        continuous = if model.continuous { "ON" } else { "OFF" },
+        tuning_mode = model.tuning_mode,
         legato = if model.legato { "ON" } else { "OFF" },
         reverb = if model.reverb_active { "ON" } else { "OFF" },
         delay = if model.delay_active { "ON" } else { "OFF" },
@@ -401,12 +390,26 @@ impl ViewModel for MidiInfo {
     }
 
     fn write_info(&self, target: &mut String) -> fmt::Result {
+        let tuning_method = match self.tuning_method {
+            Some(TuningMethod::FullKeyboard(false)) => "Single Note Tuning Change",
+            Some(TuningMethod::FullKeyboard(true)) => "Single Note Tuning Change (realtime)",
+            Some(TuningMethod::Octave1(false)) => "Scale/Octave Tuning (1-Byte)",
+            Some(TuningMethod::Octave1(true)) => "Scale/Octave Tuning (1-Byte) (realtime)",
+            Some(TuningMethod::Octave2(false)) => "Scale/Octave Tuning (2-Byte)",
+            Some(TuningMethod::Octave2(true)) => "Scale/Octave Tuning (2-Byte) (realtime)",
+            Some(TuningMethod::ChannelFineTuning) => "Channel Fine Tuning",
+            Some(TuningMethod::PitchBend) => "Pitch Bend",
+            None => "None. Change tuning mode.",
+        };
+
         writeln!(
             target,
             "Output [Alt+O]: MIDI\n\
              Device: {device}\n\
+             Tuning method: {tuning_method}\n\
              Program [Up/Down]: {program_number}",
             device = self.device,
+            tuning_method = tuning_method,
             program_number = self.program_number,
         )
     }
